linux-wireless.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
From: Stanislaw Gruszka <sgruszka@redhat.com>
To: linux-wireless@vger.kernel.org
Cc: Helmut Schaa <helmut.schaa@googlemail.com>, Felix Fietkau <nbd@nbd.name>
Subject: [PATCH v2 09/10] rt2800: use TXOP_BACKOFF for probe frames
Date: Wed, 15 Feb 2017 10:25:12 +0100	[thread overview]
Message-ID: <1487150713-3510-10-git-send-email-sgruszka@redhat.com> (raw)
In-Reply-To: <1487150713-3510-1-git-send-email-sgruszka@redhat.com>

Even if we do not set AMPDU bit in TXWI, device still can aggregate
frame and send it with rate not corresponding to requested. That mean
we can do not sent probe frames with requested rate. To prevent that
use TXOP_BACKOFF for probe frames.

Signed-off-by: Stanislaw Gruszka <sgruszka@redhat.com>
---
 drivers/net/wireless/ralink/rt2x00/rt2x00queue.c | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/drivers/net/wireless/ralink/rt2x00/rt2x00queue.c b/drivers/net/wireless/ralink/rt2x00/rt2x00queue.c
index e1660b9..a2c1ca5 100644
--- a/drivers/net/wireless/ralink/rt2x00/rt2x00queue.c
+++ b/drivers/net/wireless/ralink/rt2x00/rt2x00queue.c
@@ -372,15 +372,16 @@ static void rt2x00queue_create_tx_descriptor_ht(struct rt2x00_dev *rt2x00dev,
 
 	/*
 	 * Determine IFS values
 	 * - Use TXOP_BACKOFF for management frames except beacons
 	 * - Use TXOP_SIFS for fragment bursts
 	 * - Use TXOP_HTTXOP for everything else
 	 *
 	 * Note: rt2800 devices won't use CTS protection (if used)
 	 * for frames not transmitted with TXOP_HTTXOP
 	 */
-	if (ieee80211_is_mgmt(hdr->frame_control) &&
-	    !ieee80211_is_beacon(hdr->frame_control))
+	if ((ieee80211_is_mgmt(hdr->frame_control) &&
+	     !ieee80211_is_beacon(hdr->frame_control)) ||
+	    (tx_info->flags & IEEE80211_TX_CTL_RATE_CTRL_PROBE))
 		txdesc->u.ht.txop = TXOP_BACKOFF;
 	else if (!(tx_info->flags & IEEE80211_TX_CTL_FIRST_FRAGMENT))
 		txdesc->u.ht.txop = TXOP_SIFS;
@@ -372,15 +372,16 @@ static void rt2x00queue_create_tx_descriptor_ht(struct rt2x00_dev *rt2x00dev,
 	/*
 	 * Determine IFS values
-	 * - Use TXOP_BACKOFF for management frames except beacons
+	 * - Use TXOP_BACKOFF for probe and management frames except beacons
 	 * - Use TXOP_SIFS for fragment bursts
 	 * - Use TXOP_HTTXOP for everything else
-- 
1.8.3.1

  parent reply	other threads:[~2017-02-15  9:30 UTC|newest]

Thread overview: 12+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2017-02-15  9:25 [PATCH v2 00/10] rt2x00 patches 14.02.2017 Stanislaw Gruszka
2017-02-15  9:25 ` [PATCH v2 01/10] rt2x00: rt2800lib: move rt2800_drv_data declaration into rt2800lib.h Stanislaw Gruszka
2017-03-08 15:07   ` [v2, " Kalle Valo
2017-02-15  9:25 ` [PATCH v2 02/10] rt2800: identify station based on status WCID Stanislaw Gruszka
2017-02-15  9:25 ` [PATCH v2 03/10] rt2x00: separte filling tx status from rt2x00lib_txdone Stanislaw Gruszka
2017-02-15  9:25 ` [PATCH v2 04/10] rt2x00: separte clearing entry " Stanislaw Gruszka
2017-02-15  9:25 ` [PATCH v2 05/10] rt2x00: add txdone nomatch function Stanislaw Gruszka
2017-02-15  9:25 ` [PATCH v2 06/10] rt2x00: fixup fill_tx_status for nomatch case Stanislaw Gruszka
2017-02-15  9:25 ` [PATCH v2 07/10] rt2x00: use txdone_nomatch on rt2800usb Stanislaw Gruszka
2017-02-15  9:25 ` [PATCH v2 08/10] rt2800: status based rate flags for nomatch case Stanislaw Gruszka
2017-02-15  9:25 ` Stanislaw Gruszka [this message]
2017-02-15  9:25 ` [PATCH v2 10/10] rt2x00: fix rt2x00debug_dump_frame comment Stanislaw Gruszka

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1487150713-3510-10-git-send-email-sgruszka@redhat.com \
    --to=sgruszka@redhat.com \
    --cc=helmut.schaa@googlemail.com \
    --cc=linux-wireless@vger.kernel.org \
    --cc=nbd@nbd.name \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).